# Changelog

## [1.1.9a1](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/1.1.9a1) (2024-11-22)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/V1.1.8...1.1.9a1)

**Merged pull requests:**

- fix: workshop compat [\#159](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/pull/159) ([JarbasAl](https://github.com/JarbasAl))

## [V1.1.8](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/tree/V1.1.8) (2024-11-19)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-audio-plugin/compare/1.1.8...V1.1.8)



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
